#Example script of ss beam to demonstrate the inclusion of structures in fire in OpenSeeS 

wipe;

model BasicBuilder -ndm 2 -ndf 3;

#source external script needed to generate an I section
source Wsection.tcl; #PK Wsection includes fibersecThermal

#source necessary external script that are needed to generate deformes shape
source DisplayPlane.tcl
source DisplayModel2D.tcl

#Define nodes and coordinates
node 1 0 0;
node 2 1000 0;
node 3 2000 0;
node 4 3000 0;
node 5 4000 0;
node 6 5000 0;
node 7 6000 0;

#simply supported 
fix 1 1 1 0;
fix 7 0 1 0; 


uniaxialMaterial Steel01Thermal 1 308 2.1e5 0.01; 

# beam sections: 
set d 355;	# depth
set bf 171.5;	# flange width
set tf 11.5;	# flange thickness
set tw 7.4;	    # web thickness
set nfdw 8;		# number of fibers along dw
set nftw 1;		# number of fibers along tw
set nfbf 1;		# number of fibers along bf
set nftf 4;			# number of fibers along tf
Wsection  1 1 $d $bf $tf $tw $nfdw $nftw $nfbf $nftf
      
geomTransf Corotational 1;

#choose the section for the beam eles
set section 1

element dispBeamColumnThermal 1 1 2 5 $section 1;
element dispBeamColumnThermal 2 2 3 5 $section 1;
element dispBeamColumnThermal 3 3 4 5 $section 1;
element dispBeamColumnThermal 4 4 5 5 $section 1;
element dispBeamColumnThermal 5 5 6 5 $section 1;
element dispBeamColumnThermal 6 6 7 5 $section 1;

#output node displacements for all the nodes
recorder Node -file 1.out -time -node 1 -dof 1 2 3 disp;
recorder Node -file 2.out -time -node 2 -dof 1 2 3 disp;
recorder Node -file 3.out -time -node 3 -dof 1 2 3 disp;
recorder Node -file 4.out -time -node 4 -dof 1 2 3 disp;
recorder Node -file 5.out -time -node 5 -dof 1 2 3 disp;
recorder Node -file 6.out -time -node 6 -dof 1 2 3 disp;
recorder Node -file 7.out -time -node 7 -dof 1 2 3 disp;
#recorder Node -file 8.out -time -node 8 -dof 1 2 3 disp;

# Define DISPLAY -------------------------------------------------------------
	set  xPixels 700;	# height of graphical window in pixels
	set  yPixels 400;	# height of graphical window in pixels
	set  xLoc1 10;	# horizontal location of graphical window (0=upper left-most corner)
	set  yLoc1 400;	# vertical location of graphical window (0=upper left-most corner)
	set ViewScale 0.0000001;	# scaling factor for viewing deformed shape, it depends on the dimensions of the model

	######################################################################################
	## DisplayModel2D $ShapeType $dAmp $xLoc $yLoc $xPixels $yPixels $nEigen

	## display Node Numbers, Deformed or Mode Shape in 2D problem
	##			Silvia Mazzoni & Frank McKenna, 2006
	##
	## 	ShapeType : 	type of shape to display. # options: ModeShape , NodeNumbers , DeformedShape 
	## 	dAmp : 		relative amplification factor for deformations
	## 	xLoc,yLoc  : 	horizontal & vertical location in pixels of graphical window (0,0=upper left-most corner)
	## 	xPixels,yPixels :	width & height of graphical window in pixels
	## 	nEigen : 		if nEigen not=0, show mode shape for nEigen eigenvalue
	##	
	#######################################################################################
	
	DisplayModel2D DeformedShape $ViewScale $xLoc1 $yLoc1 $xPixels $yPixels 0

pattern Plain 1 Linear {

#CREATE UNIFORM LOADS FOR BEAMS
set  UDL -8;    
eleLoad -range 1 6 -type -beamUniform $UDL 0;
}

	constraints Plain;					# how it handles boundary conditions
	##numberer Plain;	
	numberer RCM;					# renumber dof's to minimize band-width (optimization)
	#system BandGeneral;					# how to store and solve the system of equations in the analysis (large model: try UmfPack)
	system UmfPack
	test NormUnbalance 1.0e-5 20 1;		# tolerance, max iterations
	algorithm Newton;					# use Newton's solution algorithm: updates tangent stiffness at every iteration
	
	integrator LoadControl 0.1;				# determine the next time step for an analysis, # apply gravity in 10 steps
	analysis Static;					# define type of analysis static or transient
	analyze 10;
	

	#######FIRE PART########
	puts "Fire";

	loadConst -time 0.0	;
	set HalfD [expr $d/2];
	#create fire pattern
pattern Plain 2 Linear {
	eleLoad -range 1 6 -type -beamThermal 1000 -$HalfD 1000 $HalfD; 
	#eleLoad -range 1 6 -type -beamThermal -source $fileName $locy1 $locy2 $locy3 $locy4; 
}

	#constraints Transformation
	#constraints Penalty 1e10 1e10
	constraints Plain;					# how it handles boundary conditions
	numberer Plain;						# renumber dof's to minimize band-width (optimization)
	#system BandGeneral;					# how to store and solve the system of equations in the analysis (large model: try UmfPack)
	system UmfPack
	test NormUnbalance 1.0e-4 80 1;		# tolerance, max iterations
	#test NormDispIncr 1e-6 10
	#test EnergyIncr 1.0e-8 50
	algorithm Newton;					# use Newton's solution algorithm: updates tangent stiffness at every iteration
	integrator LoadControl 0.01;
    analysis Static;
    analyze 100; #100steps to apply thermal action
	
	
	print domain.out	

puts "This example analysis is completed.";

	
